Skip to contents

As both a refinement and advancement of the unmixing process of full spectrum cytometry data, AutoSpectral provides a suite of functions/tools that work in concert to provide the user with optimal unmixing results.

Use AutoSpectral to:

  • isolate and refine clean spectral signatures

  • mitigate autofluorescence contamination in complex controls

  • unmix fcs files using standard algorithms or the hallmark AutoSpectral approach

AutoSpectral (v 1.5.7) Workflow

To maximize the success of AutoSpectral, the workflow is organized into the following logical step-wise processes:

  1. create.control.file: Generate a .csv file that contains descriptive information about your single stained controls

  2. define.flow.control: uses the result of create.control.file to convert FCS files and their associated metadata into an optimized data structure for downstream workflows

  3. clean.controls: removes autofluorescent events from cell-based controls via PCA-based gating, selects top-expressing positive events, matches universal negatives by scatter, and downsamples for speed

  4. get.fluorophore.spectra: extracts normalized [0, 1] fluorophore reference spectra from the cleaned controls and performs cosine-similarity QC against the spectral reference library

  5. (Optional) get.af.spectra: extracts autofluorescence reference spectra for use with the AutoSpectral unmixing method

  6. (Optional) get.spectral.variants: computes per-fluorophore spectral variants for per-cell fluorophore optimization during AutoSpectral unmixing

  7. unmix.fcs / unmix.folder: unmixes experiment FCS files using the extracted spectra. Supported methods are "OLS", "WLS", "Poisson", and "AutoSpectral"

Automated alternative (steps 2–4)

get.spectra.automated replaces the define.flow.controlclean.controlsget.fluorophore.spectra pipeline with a single function call, requiring no scatter gating or interactive input.

Author

Maintainer: Oliver Burton olivertburton@gmail.com (ORCID)

Authors: