Reads an Experiment (.Expt) file from SpectroFlo and extracts the spillover matrix that was used for the unmixing. Note that the information stored in the SpectroFlo .Expt files for spillover is sometimes perfect for unmixing and is at other times very odd. Unfortunately, it appears the information on spillover values is not always accurately encoded in the .Expt files, so this function may be deprecated going forward.
Usage
read.spectroflo.expt(
expt.file,
output.dir,
output.filename = "SpectroFlo_spillover_matrix.csv",
fcs.file = NULL
)Arguments
- expt.file
File name and path to the .Expt file to be read.
- output.dir
Directory where the spillover .csv file will be written.
- output.filename
Name for the output spillover file. Default is
"SpectroFlo_spillover_matrix.csv".- fcs.file
File name and path to an FCS file to be read. Optional, but inclusion of an FCS file will allow for the detector names (channels) to be added to the returned spillover matrix.