This function generates scatter plots for matching positive and negative expression data, selected based on scatter parameters gates.
Arguments
- pos.expr.data
A matrix containing the positive expression data.
- neg.expr.data
A matrix containing the negative expression data.
- fluor.name
A character string specifying the fluorophore name.
- scatter.param
A character vector specifying the scatter parameters.
- asp
The AutoSpectral parameter list. Prepare using
get.autospectral.param.