Faster solver for per-cell optimization workflow. Performs spectral unmixing using weighted least squares.
Arguments
- raw.data
Expression data from raw FCS files. Cells in rows and detectors in columns. Columns should be fluorescent data only and must match the columns in spectra.
- spectra
Spectral signatures of fluorophores, normalized between 0 and 1, with fluorophores in rows and detectors in columns.
- weights
The weighting values for the detectors. No checks are performed on supplied weights;
unmix.wlsshould be used for most cases. Default isNULL, in which case weighting is computed from channel means ofraw.data, floored atnoise.floor.- noise.floor
Numeric, default
125. Lower clamp on mean channel signal before inversion whenweights = NULL. Signal units, same convention asnoise.floorelsewhere in the package. Ignored ifweightsis supplied.