A small helper function to check for non-standard or crash-inducing input when
users supply gates to define.flow.control().
Arguments
- gate.list
Named list of gates. To use this, pre-define the gates using
define.gate.landmarks()and/ordefine.gate.density(), ensure that the names of the gates correspond to the names in thecontrol.def.file, and ensure that thegate.namecolumn has been filled in for thecontrol.def.file.- control.table
Dataframe or table of the control file, read in via
define.flow.control()and cleaned up by that function.- asp
The AutoSpectral parameter list defined using
get.autospectral.param.