A light weight FCS file binary writer based on flowstate. Lower memory usage
and faster than flowCore.
References
Laniewski, Nathan. flowstate. https://github.com/nlaniewski/flowstate
Ellis B, Haaland P, Hahne F, Le Meur N, Gopalakrishnan N, Spidlen J, Jiang M, Finak G (2025). flowCore: Basic structures for flow cytometry data. doi:10.18129/B9.bioc.flowCore https://bioconductor.org/packages/flowCore